# Navidrome On Console Player

NOCP (Navidrome On Console Player) is a console audio player designed to be powerful and easy to use inpired bien MOCP (Music On Console Player).

[Navidrome](https://www.navidrome.org/) is an open source web-based music collection server and streamer. It gives you freedom to listen to your music collection from any browser or mobile device. It's like your personal Spotify!

![custom-field](nocpglobal.png "Nocp")

## install

install by [pypi](https://pypi.org/project/nocp/)

> pip install nocp

## usage

> nocp --help

> nocp --server-url http://myserver-navidrome/rest --username myusername --password mypassword --lang en_US

after just

> nocp

You can access to three views

- listing song (shorcut **m**)
- listing radio (shorcut **r**)
- listing playlist (shorcut **l**)
- listing podcasts (shortcut **o**)

You can access to

- help (shorcut **h**)
- volume (shorcut **v**)

You can listen to a song by selecting it and pressing "Enter"

![custom-field](nocpaction.png "help")

List of available languages

- English
- French
- German
- Spanish
- Italian
- Portuguese

For add podcasts it's necessary to add in .nocp/config.ini value in *podcasts* parameter

```
podcasts = [
        {"name": "Rdv Tech", "url": "https://feedpress.me/rdvtech"},
        {"name": "Affaires Sensibles", "url": "https://radiofrance-podcast.net/podcast09/podcast_0b91efaf-26e6-11e4-907f-782bcb6744eb.xml"}
    ]
```


## addshorcut

on ubuntu, create file ~/.local/share/applications/nocp.desktop

```
[Desktop Entry]
Type=Application
Name=Nocp
Exec=gnome-terminal -- bash -c 'nocp; exit;'
Icon=utilities-terminal
Terminal=false
```

and

> chmod +x ~/.local/share/applications/nocp.desktop

## development

Before propose your merge

> flake8

for push on pypi

> python -m build
> twine upload dist/*


## todo

- random listen
